from datetime import date
from zona.models import Metadata
from zona.builder import split_metadata, discover
from pathlib import Path


def test_split_metadata(tmp_path: Path):
    content = """---
title: Test Post
date: 2025-06-03
description: This is a test.
---

# Hello World
    """
    test_file = tmp_path / "test.md"
    test_file.write_text(content)
    meta, content = split_metadata(test_file)

    assert isinstance(meta, Metadata)
    assert meta.title == "Test Post"
    assert meta.description == "This is a test."
    assert meta.date == date(2025, 6, 3)
    assert content == "# Hello World"


def test_discover(tmp_path: Path):
    contentd = tmp_path / "content"
    staticd = contentd / "static"
    templatesd = tmp_path / "templates"
    outd = tmp_path / "out"

    for d in [contentd, staticd, templatesd, outd]:
        d.mkdir()
    md_file = contentd / "post.md"
    md_file.write_text("""---
title: Test Post
date: 2025-06-03
description: This is a test.
---

# Hello World
    """)

    style = staticd / "style.css"
    style.write_text("""
p {
  color: red;
  text-align: center;
}
""")

    items = discover(tmp_path, outd)

    assert len(items) == 2

    md_item = items[0]
    assert md_item.source == md_file
    assert md_item.destination.name == "post.md"
    assert md_item.destination.is_relative_to(outd)
    assert md_item.url == "post.md"
    assert isinstance(md_item.metadata, Metadata)
    assert md_item.metadata.title == "Test Post"
    assert md_item.content.strip() == "# Hello World"

    st_item = items[1]
    assert st_item.source == style
    assert st_item.destination.name == "style.css"
    assert st_item.destination.is_relative_to(outd)
    assert st_item.url == "static/style.css"
    assert st_item.metadata is None
